@@ -7,9 +7,7 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 import asyncio
-import logging
 import os
-from typing import Any
 from typing import Awaitable
 
 from headless.ext.shopify import AdminClient
@@ -17,19 +15,23 @@ from headless.ext.shopify.v2023_1 import Order
 
 
 async def main():
-    logger: logging.Logger = logging.getLogger('headless.client')
-    logger.setLevel(logging.INFO)
-    params: dict[str, Any]  = {
+    params = {
         'access_token': os.environ['SHOPIFY_ACCESS_TOKEN'],
         'domain': os.environ['SHOPIFY_SHOP_DOMAIN']
     }
     async with AdminClient(**params) as client:
+        orders: list[Order] = [x async for x in client.list(Order)]
+        if not orders:
+            print("Your shop needs at least one order for this example to work.")
+            raise SystemExit
         requests: list[Awaitable[Order]] = []
-        for _ in range(50):
-            requests.append(client.retrieve(Order, 5273119949113))
-        orders = await asyncio.gather(*requests)
-        print(orders[-1].json(indent=2))
 
+        # The Shopify Admin API limits the request to 40 per minute,
+        # but the code below will not raise any errors related to
+        # rate limiting.
+        for _ in range(60):
+            requests.append(client.retrieve(Order, orders[0].id))
+        orders = await asyncio.gather(*requests)
 
 
 if __name__ == '__main__':
