@@ -6,15 +6,25 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+from typing import Any
+
+from .deferredresource import DeferredResource
 from .linearbackoff import LinearBackoff
 from .resource import Resource # type: ignore
 from .resourcemeta import ResourceMeta
 from .resourcemetaclass import ResourceMetaclass
+from .resourcereference import ResourceReference
 
 
 __all__: list[str] = [
+    'DeferredResource',
     'LinearBackoff',
     'Resource',
     'ResourceMeta',
     'ResourceMetaclass',
-]
\ No newline at end of file
+    'ResourceReference',
+]
+
+
+def Reference(model: type[Resource], attname: str) -> Any:
+    return ResourceReference(model, attname)
\ No newline at end of file
